#!/usr/bin/env python3
#encoding utf-8

##Base:
import os

__all__ = ["FORMDEBUG"]

FORMDEBUG = True
